@@ -3,11 +3,20 @@
 package Devel::AssertOS::QNX;
 
 use Devel::CheckOS;
+use strict;
+use warnings;
+no warnings 'redefine';
 
-$VERSION = '1.1';
+our $VERSION = '1.2';
 
 sub matches { return qw(QNX::v4 QNX::Neutrino); }
 sub os_is { Devel::CheckOS::os_is(matches()); }
+sub expn {
+join("\n", 
+"All versions of QNX match this, as well as (possibly) a more specific",
+"match"
+)
+}
 Devel::CheckOS::die_unsupported() unless(os_is());
 
 =head1 COPYRIGHT and LICENCE
